@@ -13,8 +13,8 @@ TEXTUREPATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                            'textures/')
 print(SOUNDPATH, TEXTUREPATH)
 ALL = [
-    'apple.png', 'banana.png', 'bone.png', 'bottle.png', 'chick.png',
-    'cola.png', 'fish.png'
+    'apple.png', 'banana.png', 'bone.png', 'cup.png', 'chick.png', 'cola.png',
+    'fish.png'
 ]
 
 
@@ -86,11 +86,14 @@ class Kitchen(arcade.Window):
     def __init__(self, width=400, height=600, title='GAME'):
         super().__init__(width, height, title)
 
-    def build(self, l=4, r=2, num=1):
+    def build(self, l=4, r=2, num=1, bgpic=None):
 
         self.rubbish_textures = [TEXTUREPATH + 'paper.png']
         if num > 1 and num <= len(ALL):
-            self.rubbish_textures = random.sample(ALL, num)
+            lst = random.sample(ALL, num)
+            self.rubbish_textures = [TEXTUREPATH + pic for pic in lst]
+        elif num > len(ALL):
+            self.rubbish_textures = [TEXTUREPATH + pic for pic in ALL]
         self.has_bomb = False
         self.allow_music = True
         self.is_music_start = False
@@ -107,7 +110,10 @@ class Kitchen(arcade.Window):
 
         self.music = arcade.Sound(SOUNDPATH + "happy.mp3")
         self.bomb = arcade.Sound(SOUNDPATH + 'bomb.wav', streaming=True)
-        self.bgname = TEXTUREPATH + 'kitchen.jpg'
+        if bgpic:
+            self.bgname = bgpic
+        else:
+            self.bgname = TEXTUREPATH + 'kitchen.jpg'
         self.background_image = arcade.load_texture(self.bgname)
 
         self.db_left = Dustbin(t=l, s=DUSTBIN_SCALE)
@@ -160,14 +166,13 @@ class Kitchen(arcade.Window):
         global RUBBISH_SCALE
         RUBBISH_SCALE = s
 
-    def set_bg(self, bg):
-        self.bgname = bg
-
-    def add_rb(self, name):
+    def add_rub(self, name):
         if name not in self.rubbish_textures:
-            #前插是为了保证bomb.png必须在rubbish_textures的最后一个
             self.rubbish_textures.insert(0, TEXTUREPATH + name)
 
+    def add_my_rub(self, pic):
+        self.rubbish_textures.insert(0, pic)
+
     def set_speed(self, num):
         if num >= 0:
             self.frames = num
